@@ -5,7 +5,7 @@ use warnings;
 
 use Module::Pluggable require => 1;
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 1;
 
@@ -57,6 +57,7 @@ Returns list of plugin module name strings.
  # List of plugins:
  # - MARC::Validator::Plugin::Field008
  # - MARC::Validator::Plugin::Field020
+ # - MARC::Validator::Plugin::Field040
  # - MARC::Validator::Plugin::Field260
  # - MARC::Validator::Plugin::Field264
 
@@ -80,8 +81,15 @@ L<http://skim.cz>
 
 BSD 2-Clause License
 
+=head1 ACKNOWLEDGEMENTS
+
+Development of this software has been made possible by institutional support
+for the long-term strategic development of the National Library of the Czech
+Republic as a research organization provided by the Ministry of Culture of
+the Czech Republic (DKRVO 2024–2028), Area 11: Linked Open Data.
+
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
